@@ -6,7 +6,8 @@ class Git:
     def get_log(
         self, max_line_count: int = None, first_parent: bool = False
     ) -> Command:
-        format = "hash>>%H<<hash%ntitle>>%s<<title%nbody>>%b<<body%n"
+        # format = "hash>>%H<<hash%ntitle>>%s<<title%nbody>>%b<<body%n"
+        format: str = "hash>>%H%nauthor>>%cN%nauthor_mail>>%cE%nauthor_date>>%ct%ntitle>>%s%nbody>>%b<<body%n"
         delimiter = COMMIT_DELIMITER
         if first_parent:
             command = f'git log --first-parent --format="{format}"{delimiter}'
